==> touhoulittlemaid-fabric-1.20.1-0.1.2-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemGarageKit.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.TileEntityItemStackGarageKitRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.resource.CustomPackLoader;
import com.github.tartaricacid.touhoulittlemaid.client.resource.pojo.MaidModelInfo;
import com.github.tartaricacid.touhoulittlemaid.compat.ysm.YsmCompat;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import com.github.tartaricacid.touhoulittlemaid.inventory.tooltip.YsmMaidInfo;
import com.github.tartaricacid.touhoulittlemaid.util.ParseI18n;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1299;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_5250;
import net.minecraft.class_756;
import net.minecraft.class_7923;
import java.util.Objects;

public class ItemGarageKit extends class_1747 implements IItemRenderer {
    private static final String ENTITY_INFO = "EntityInfo";
    private static final String DEFAULT_ENTITY_ID = "touhou_little_maid:maid";
    private static final String DEFAULT_MODEL_ID = "touhou_little_maid:hakurei_reimu";
    private static final String ENTITY_ID_TAG_NAME = "id";
    private static final class_2487 DEFAULT_DATA = getDefaultData();

    public ItemGarageKit() {
        super(InitBlocks.GARAGE_KIT, (new class_1792.class_1793()).method_7889(1));
    }

    private static boolean hasMaidData(class_1799 stack) {
        return stack.method_7985() && !Objects.requireNonNull(stack.method_7969()).method_10562(ENTITY_INFO).method_33133();
    }

    public static class_2487 getMaidData(class_1799 stack) {
        if (hasMaidData(stack)) {
            return Objects.requireNonNull(stack.method_7969()).method_10562(ENTITY_INFO);
        }
        return DEFAULT_DATA;
    }

    private static class_2487 getDefaultData() {
        class_2487 data = new class_2487();
        data.method_10582(ENTITY_ID_TAG_NAME, DEFAULT_ENTITY_ID);
        data.method_10582(EntityMaid.MODEL_ID_TAG, DEFAULT_MODEL_ID);
        // 默认数据需要强制指定 YSM 渲染为空
        data.method_10556(EntityMaid.IS_YSM_MODEL_TAG, false);
        return data;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_2561 method_7864(class_1799 stack) {
        // 仅在客户端添加这个名称
        if (FabricLoader.getInstance().getEnvironmentType() == EnvType.CLIENT) {
            // 手办名字前缀
            class_5250 prefix = class_2561.method_43471("block.touhou_little_maid.garage_kit.prefix");
            class_2487 data = getMaidData(stack);

            String entityId = data.method_10558(ENTITY_ID_TAG_NAME);
            // 如果是其他实体，那么不需要显示 model id
            if (!entityId.equals(DEFAULT_ENTITY_ID)) {
                class_1299<?> entityType = class_7923.field_41177.method_10223(new class_2960(entityId));
                return prefix.method_10852(entityType.method_5897());
            }

            // 优先使用 YSM 模型名称
            if (YsmCompat.isInstalled()) {
                YsmMaidInfo ysmMaidInfo = YsmCompat.getYsmMaidInfo(data);
                if (ysmMaidInfo.isYsmModel()) {
                    class_5250 name = ysmMaidInfo.name();
                    if (name == null || name.equals(class_2561.method_43473())) {
                        return prefix.method_27693(ysmMaidInfo.modelId());
                    }
                    return prefix.method_10852(name);
                }
            }

            // 然后才是默认模型名
            String modelId = data.method_10558(EntityMaid.MODEL_ID_TAG);
            MaidModelInfo info = CustomPackLoader.MAID_MODELS.getInfo(modelId).orElse(null);
            if (info != null) {
                return prefix.method_10852(ParseI18n.parse(info.getName()));
            }
            return super.method_7864(stack);
        }
        return super.method_7864(stack);
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_756 getCustomRenderer() {
        class_310 minecraft = class_310.method_1551();
        return new TileEntityItemStackGarageKitRenderer(minecraft.method_31975(), minecraft.method_31974());
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.2-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/item/ItemGarageKit.java <==
package com.github.tartaricacid.touhoulittlemaid.item;

import cn.sh1rocu.touhoulittlemaid.api.extension.IItemRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.tileentity.TileEntityItemStackGarageKitRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.resource.CustomPackLoader;
import com.github.tartaricacid.touhoulittlemaid.client.resource.pojo.MaidModelInfo;
import com.github.tartaricacid.touhoulittlemaid.compat.ysm.YsmCompat;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitBlocks;
import com.github.tartaricacid.touhoulittlemaid.inventory.tooltip.YsmMaidInfo;
import com.github.tartaricacid.touhoulittlemaid.util.ParseI18n;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1299;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2487;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_5250;
import net.minecraft.class_756;
import net.minecraft.class_7923;
import java.util.Objects;

public class ItemGarageKit extends class_1747 implements IItemRenderer {
    private static final String ENTITY_INFO = "EntityInfo";
    private static final String DEFAULT_ENTITY_ID = "touhou_little_maid:maid";
    private static final String DEFAULT_MODEL_ID = "touhou_little_maid:hakurei_reimu";
    private static final String ENTITY_ID_TAG_NAME = "id";
    private static final class_2487 DEFAULT_DATA = getDefaultData();

    public ItemGarageKit() {
        super(InitBlocks.GARAGE_KIT, (new class_1792.class_1793()).method_7889(1));
    }

    private static boolean hasMaidData(class_1799 stack) {
        return stack.method_7985() && !Objects.requireNonNull(stack.method_7969()).method_10562(ENTITY_INFO).method_33133();
    }

    public static class_2487 getMaidData(class_1799 stack) {
        if (hasMaidData(stack)) {
            return Objects.requireNonNull(stack.method_7969()).method_10562(ENTITY_INFO);
        }
        return DEFAULT_DATA;
    }

    private static class_2487 getDefaultData() {
        class_2487 data = new class_2487();
        data.method_10582(ENTITY_ID_TAG_NAME, DEFAULT_ENTITY_ID);
        data.method_10582(EntityMaid.MODEL_ID_TAG, DEFAULT_MODEL_ID);
        // 默认数据需要强制指定 YSM 渲染为空
        data.method_10556(EntityMaid.IS_YSM_MODEL_TAG, false);
        return data;
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_2561 method_7864(class_1799 stack) {
        // 仅在客户端添加这个名称
        if (FabricLoader.getInstance().getEnvironmentType() == EnvType.CLIENT) {
            // 手办名字前缀
            class_5250 prefix = class_2561.method_43471("block.touhou_little_maid.garage_kit.prefix");
            class_2487 data = getMaidData(stack);

            String entityId = data.method_10558(ENTITY_ID_TAG_NAME);
            // 如果是其他实体，那么不需要显示 model id
            if (!entityId.equals(DEFAULT_ENTITY_ID)) {
                class_1299<?> entityType = class_7923.field_41177.method_10223(new class_2960(entityId));
                return prefix.method_10852(entityType.method_5897());
            }

            // 优先使用 YSM 模型名称
            if (YsmCompat.isInstalled()) {
                YsmMaidInfo ysmMaidInfo = YsmCompat.getYsmMaidInfo(data);
                if (ysmMaidInfo.isYsmModel()) {
                    class_5250 name = ysmMaidInfo.name();
                    if (name == null || name.equals(class_2561.method_43473())) {
                        return prefix.method_27693(ysmMaidInfo.modelId());
                    }
                    return prefix.method_10852(name);
                }
            }

            // 然后才是默认模型名
            String modelId = data.method_10558(EntityMaid.MODEL_ID_TAG);
            MaidModelInfo info = CustomPackLoader.MAID_MODELS.getInfo(modelId).orElse(null);
            if (info != null) {
                return prefix.method_10852(ParseI18n.parse(info.getName()));
            }
            return super.method_7864(stack);
        }
        return super.method_7864(stack);
    }

    @Override
    @Environment(EnvType.CLIENT)
    public class_756 getCustomRenderer() {
        return TileEntityItemStackGarageKitRenderer.INSTANCE.get();
    }
}
